==> openser-1.2.2-tls_src.tar.gz: openser-1.2.2-tls/modules/presence/presentity.h <==
/*
 * $Id: presentity.h 2075 2007-04-25 14:35:33Z anca_vamanu $
 *
 * presence module - presence server implementation
 *
 * Copyright (C) 2006 Voice Sistem S.R.L.
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * History:
 * --------
 *  2006-08-15  initial version (anca)
 */

#ifndef PRESENTITY_H
#define PRESENTITY_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <libxml/parser.h>
#include <time.h>
#include "../../str.h"
#include "../../parser/msg_parser.h"
typedef struct presentity
{
	int presid;
	str user;
	str domain;
	int expires;
	int received_time;
	str etag;
//	xmlDocPtr body;

} presentity_t;

/* create new presentity */
int new_presentity(str* domain,str* user, int expires, int received_time, 
		str* t_tag, presentity_t** p);

/* update presentity in database */
int update_presentity(struct sip_msg* msg, presentity_t* p, str* body, int t_new);

/* free memory */
void free_presentity(presentity_t* p);

/* Run a time handler for a presentity  */
//int timer_presentity(presentity_t * p);


#endif

==> openser-1.2.3-tls_src.tar.gz: openser-1.2.3-tls/modules/presence/presentity.h <==
/*
 * $Id: presentity.h 2979 2007-10-23 14:28:22Z anca_vamanu $
 *
 * presence module - presence server implementation
 *
 * Copyright (C) 2006 Voice Sistem S.R.L.
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * History:
 * --------
 *  2006-08-15  initial version (anca)
 */

#ifndef PRESENTITY_H
#define PRESENTITY_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <libxml/parser.h>
#include <time.h>
#include "../../str.h"
#include "../../parser/msg_parser.h"
typedef struct presentity
{
	int presid;
	str user;
	str domain;
	int expires;
	int received_time;
	str etag;
//	xmlDocPtr body;

} presentity_t;

/* create new presentity */
int new_presentity(str* domain,str* user, int expires, int received_time, 
		str* t_tag, presentity_t** p);

/* update presentity in database */
int update_presentity(struct sip_msg* msg, presentity_t* p, str* body,
		int t_new, int* sent_reply);

/* free memory */
void free_presentity(presentity_t* p);

/* Run a time handler for a presentity  */
//int timer_presentity(presentity_t * p);


#endif
